# ABSTRACT: An Array Object Role for Perl 5
package Data::Object::Role::Array;

use 5.10.0;
use Moo::Role;

our $VERSION = '0.02'; # VERSION

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Data::Object::Role::Array - An Array Object Role for Perl 5

=head1 VERSION

version 0.02

=head1 SYNOPSIS

    use Data::Object::Role::Array;

=head1 DESCRIPTION

Data::Object::Role::Array provides functions for operating on Perl 5 array
references.

=head1 SEE ALSO

=over 4

=item *

L<Data::Object::Role::Array>

=item *

L<Data::Object::Role::Code>

=item *

L<Data::Object::Role::Float>

=item *

L<Data::Object::Role::Hash>

=item *

L<Data::Object::Role::Integer>

=item *

L<Data::Object::Role::Number>

=item *

L<Data::Object::Role::Scalar>

=item *

L<Data::Object::Role::String>

=item *

L<Data::Object::Role::Undef>

=item *

L<Data::Object::Role::Universal>

=back

=head1 AUTHOR

Al Newkirk <anewkirk@ana.io>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Al Newkirk.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
